pub type IInkCommitRequestHandler = *mut ::core::ffi::c_void;
pub type IInkD2DRenderer = *mut ::core::ffi::c_void;
pub type IInkD2DRenderer2 = *mut ::core::ffi::c_void;
pub type IInkDesktopHost = *mut ::core::ffi::c_void;
pub type IInkHostWorkItem = *mut ::core::ffi::c_void;
pub type IInkPresenterDesktop = *mut ::core::ffi::c_void;
#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
pub const InkD2DRenderer: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x4044e60c_7b01_4671_a97c_04e0210a07a5);
#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
pub const InkDesktopHost: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x062584a6_f830_4bdc_a4d2_0a10ab062b1d);
#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
pub type INK_HIGH_CONTRAST_ADJUSTMENT = i32;
#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
pub const USE_SYSTEM_COLORS_WHEN_NECESSARY: INK_HIGH_CONTRAST_ADJUSTMENT = 0i32;
#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
pub const USE_SYSTEM_COLORS: INK_HIGH_CONTRAST_ADJUSTMENT = 1i32;
#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
pub const USE_ORIGINAL_COLORS: INK_HIGH_CONTRAST_ADJUSTMENT = 2i32;
